import QtQuick 1.1
import com.nokia.meego 1.1
import QtMultimediaKit 1.1

import "Utils.js" as Utils

Page {
    id: albumInfo
    orientationLock: PageOrientation.LockPortrait
    property string albumId: ""
    property string artistName: ""
    property string artistGenre: ""
    property string albumYear: ""

    signal trackChanged(variant track);

    Component.onCompleted: {
        console.log("Album page!")
        var url = "http://music.yandex.ru/handlers/album.jsx?album=" + albumId
        Utils.httpRequest("GET", url, getTracks);
        mainPage.playerAlias.endOfMedia.connect(albumInfo.nextTrack);
        trackChanged.connect(mainPage.playerAlias.sendReqest);
    }

    function getTracks(data) {
        if(data !== "error") {
            var res = JSON.parse(data);
            var artists = [];
            albumLabel.text = res.title
            for(var a in res.artists) {
                artists.push(res.artists[a].name)
            }
            artists = artists.join(', ');
            for(var i in res.volumes) {
                for(var j in res.volumes[i]) {
                    var item = res.volumes[i][j]
                    var cover = "noCover.png";
                    if(res.coverUri) {
                        cover = Utils.getCoverSource(res.coverUri);
                        albumImage.source = cover;
                    }
                    trackModel.append({artistId: res.artists[0].id, artists: artists, track: item.id, coverUri: cover, title: item.title, storageDir: item.storageDir, durationMs: item.durationMs, album: res.title, albumYear: res.year})
                }
            }
        }
    }

    function nextTrack(){
        if(listView.count > 0 && listView.currentIndex < listView.count){
            mainPage.changeTrack = true;
            listView.incrementCurrentIndex();
            trackChanged(trackModel.get(listView.currentIndex));
        }
    }

    ListModel {
        id: trackModel
    }

    Component {
        id: trackDelegate
        TrackDelegate {
            height: 90
            width: parent.width
            trackId: track
            iconSorce: coverUri
            itemText: title
            albumText: "<b>Альбом:</b> " + album
            yearText: "<b>Год:</b> " + albumYear
            trackSource: storageDir
            duration: durationMs
            z: 3

            onAddToPlaylist: {
//storageDir: trackSource, track: trackId, coverUri: iconSorce, title: itemText.text
                //playlist, artist, artistId, track, trackId, storageDir, art
                var currPlaylist = Utils.getCurrentPlayList();
                Utils.addToPlaylist(currPlaylist, artists, artistId, title, track, album, albumId, storageDir, coverUri, albumYear, durationMs);
            }
        }
    }

    Item {
        id: albumHeader
        width: parent.width
        height: 220
        Image {
            id: albumImage
            anchors.left: parent.left
            anchors.leftMargin: 5
            anchors.verticalCenter: parent.verticalCenter
            width: 200
            height: 200
            fillMode: Image.PreserveAspectFit
            smooth: true
            source: "noCover.png"
        }
        Label {
            id: albumLabel
            anchors.left: albumImage.right
            anchors.leftMargin: 10
            anchors.right: parent.right
            anchors.rightMargin: 10
            anchors.top: albumImage.top
            wrapMode: Text.WordWrap
            horizontalAlignment: Text.AlignHCenter
            text: "Bla bla bla"
        }
        Text {
            id: artist
            anchors.bottom: genre.top
            anchors.bottomMargin: 5
            anchors.left: albumImage.right
            anchors.leftMargin: 5
            anchors.right: parent.right
            anchors.rightMargin: 5
            wrapMode: Text.WordWrap
            text: artistName
        }
        Text {
            id: genre
            anchors.bottom: albumImage.bottom
            anchors.left: albumImage.right
            anchors.leftMargin: 5
    //        anchors.right: parent.right
    //        anchors.rightMargin: 5
            wrapMode: Text.WordWrap
            text: artistGenre
            opacity: 0.8
        }
        Text {
            id: year
            anchors.bottom: albumImage.bottom
            anchors.left: genre.right
            anchors.leftMargin: 5
            anchors.right: parent.right
            anchors.rightMargin: 5
            wrapMode: Text.WordWrap
            text: albumYear
            opacity: 0.8
        }
        Delimeter {
            width: parent.width * 0.95
        }
    }

    ListView {
        id: listView
        anchors.top: albumHeader.bottom
        anchors.left: parent.left
        anchors.right: parent.right
        anchors.bottom: playerItem.top
        clip: true
        spacing: 5
        model: trackModel
        delegate: trackDelegate
//        highlight: Rectangle { color: "lightsteelblue"; radius: 5 }
        focus: true
    }
    Item {
        id: playerItem
        anchors.left: parent.left
        anchors.right: parent.right
        anchors.bottom: parent.bottom
        height: mainPage.playerAlias.height;
        visible: mainPage.playerAlias.trackTitle!==""?true:false;

        Delimeter {
            anchors.top: parent.top
            width: parent.width
        }

        Text {
            id: title
            anchors.left: parent.left //currentTrack.right
            anchors.leftMargin: 10
            anchors.right: parent.right
            anchors.rightMargin: 10
            anchors.top: parent.top
            anchors.topMargin: 15
//            anchors.verticalCenter: parent.verticalCenter
            wrapMode: Text.WordWrap
            horizontalAlignment: Text.AlignHCenter
            font.pixelSize: 26
            text: mainPage.playerAlias.trackTitle
        }
        Slider {
            anchors.left: currentTrackTime.right
            anchors.leftMargin: 10
            anchors.right: trackDurationTime.left
            anchors.rightMargin: 10
//            anchors.bottom: parent.bottom
            anchors.verticalCenter: currentTrackTime.verticalCenter
            value: mainPage.playerAlias.position
            maximumValue: mainPage.playerAlias.slider.maximumValue
            valueIndicatorVisible: true
            valueIndicatorText: ((value/maximumValue)*100).toFixed(2) + "%"
            onValueChanged: {
                if(pressed) {
                    mainPage.playerAlias.position = value;
                    valueIndicatorText = ((value/maximumValue)*100).toFixed(2) + "%"
                }
            }
            onPressedChanged: {
                if(pressed) {
                    mainPage.playerAlias.pause()
                } else {
                    mainPage.playerAlias.position = value;
                    mainPage.playerAlias.play()
                }
            }
        }
        Text {
            id: currentTrackTime
            anchors.left: parent.left
            anchors.leftMargin: 10
            anchors.bottom: parent.bottom
            anchors.bottomMargin: 15
            text: Utils.getDurationTime(mainPage.playerAlias.position)
        }
        Text {
            id: trackDurationTime
            anchors.right: parent.right
            anchors.rightMargin: 10
            anchors.bottom: parent.bottom
            anchors.bottomMargin: 15
            text: Utils.getDurationTime(mainPage.playerAlias.slider.maximumValue)
        }

        onVisibleChanged: {
            console.log("Item", mainPage.playerAlias.visible, mainPage.playerAlias.trackTitle, mainPage.playerAlias.icon)
        }
    }


    tools: ToolBarLayout {
        id: tools
        ToolIcon {
            id: backButton
            platformIconId: "toolbar-back"
            onClicked: {
//                mainPage.playerAlias.stop();
                pageStack.pop();
            }
        }
        ToolIcon {
            id: prevButton
            iconId: "toolbar-mediacontrol-previous"
            onClicked: {
                if(listView.count > 0 && listView.currentIndex > 0){
                    mainPage.playerAlias.pause();
                    mainPage.changeTrack = true;
                    listView.decrementCurrentIndex();
                    trackChanged(trackModel.get(listView.currentIndex));
                }
            }
        }

        ToolIcon {
            id: playerButton
            iconId: mainPage.playerAlias.buttonIcon
            onClicked: {
                if(mainPage.playerAlias.isPlaying && !mainPage.playerAlias.isPaused) {
                    mainPage.playerAlias.pause();
                } else {
                    mainPage.playerAlias.play();
                }
            }
        }
        ToolIcon {
            id: nextButton
            iconId: "toolbar-mediacontrol-next"
            onClicked: {
                if(listView.count > 0 && listView.currentIndex < listView.count){
                    mainPage.playerAlias.pause();
                    mainPage.changeTrack = true;
                    listView.incrementCurrentIndex();
                    trackChanged(trackModel.get(listView.currentIndex));
                }
            }
        }
        ToolIcon {
            visible: true
            enabled: false
        }
    }
}
