import QtQuick 1.1

import com.nokia.meego 1.1

import "Utils.js" as Utils

Page {
    orientationLock: PageOrientation.LockPortrait
    property string artistId: ""

    Component.onCompleted: {
        var url = "http://music.yandex.ru/handlers/artist.jsx?artist=" + artistId
        Utils.httpRequest("GET", url, getAlbums);
    }

    function getAlbums(data) {
        if(data !== "error") {
            var res = JSON.parse(data);
            artistTitle.text = res.artist.name;
            var genres = res.artist.genres;
            artistGenres.text = "<b>Жанры:</b> " + genres.join(', ');
            if (res.artist.cover) {
                artistCover.source = Utils.getCoverSource(res.artist.cover.uri);
            }
            for(var i in res.albums) {
                var artists = [];
                for(var j in res.albums[i].artists) {
                    artists.push(res.albums[i].artists[j].name);
                }
                var names = artists.join(', ');
                var cover = Utils.getCoverSource(res.albums[i].coverUri);
                albumModel.append({id: res.albums[i].id, coverUri: cover, title: res.albums[i].title, year: res.albums[i].year, genre: res.albums[i].genre, artists: names});
            }
        }
    }

    ListModel {
        id: albumModel
    }

    Component {
        id: albumDelegate
        AlbumDelegate {
            height: 120
            width: parent.width
            iconSorce: coverUri
            itemText: title
            artistText: "<b>Исполнитель:</b> " + artists
            genreText: "<b>Жанр:</b> " + genre
            yearText: "<b>Год:</b> " + year
            albumId: id
            z: 3
        }
    }

    Item {
        id: info
        anchors.top: parent.top
        height: 220
        width: parent.width

        Text {
            id: artistTitle
            anchors.verticalCenter: parent.verticalCenter
            anchors.left: parent.left
            anchors.leftMargin: 10
            anchors.right: artistCover.left
            anchors.rightMargin: 10
            wrapMode: Text.WordWrap
            horizontalAlignment: Text.AlignHCenter
            font.family: "Times"
            font.pixelSize: 24
            text: qsTr("text")
        }
        Text {
            id: artistGenres
            anchors.left: parent.left
            anchors.leftMargin: 10
            anchors.bottom: parent.bottom
            anchors.bottomMargin: 10
            text: qsTr("text")
        }
        Image {
            id: artistCover
            anchors.right: parent.right
            anchors.rightMargin: 10
            anchors.verticalCenter: parent.verticalCenter
            height: 200
            width: 200
            fillMode: Image.PreserveAspectFit
            smooth: true
            source: "noCover.png"
        }
        Delimeter {
            width: parent.width * 0.98
        }
    }

    ListView {
        anchors.top: info.bottom
        anchors.left: parent.left
        anchors.right: parent.right
        anchors.bottom: parent.bottom
        clip: true
        spacing: 5
        model: albumModel
        delegate: albumDelegate
    }

    tools: ToolBarLayout {
        id: tools
        ToolIcon {
            platformIconId: "toolbar-back"
            onClicked: {
                pageStack.pop();
            }
        }
    }
}

