import QtQuick 1.1
import com.nokia.meego 1.1
import com.nokia.extras 1.1     // Extras

import "Utils.js" as Utils

Page {
    orientationLock: PageOrientation.LockPortrait
    property bool changeTrack: false
    property alias playerAlias: player

    Component.onCompleted: {
        Utils.initialize();
        if(Utils.getCurrentPlayList() === "Error") {
            Utils.setPlaylist("Default");
        }
    }

    function getAlboms(rawdata) {
        if(rawdata !== "error") {
//            console.log(data)
            var data = rawdata.items;
            albumContent.total = parseInt(rawdata.total);
            for(var i in data) {
                var artists = [];
                for(var j in data[i].artists) {
                    artists.push(data[i].artists[j].name);
                }
                var names = artists.join(',');
                var cover = "noCover.png"
                if(data[i].coverUri) {
                    cover = Utils.getCoverSource(data[i].coverUri);
                }
//                console.log(data[i].year, data[i].genre, names)
                albumModel.append({id: data[i].id, coverUri: cover, title: data[i].title, year: data[i].year, genre: data[i].genre, artists: names});
            }
        }
    }

    function getArtists(rawdata) {
        if(rawdata !== "error") {
//            console.log(data)
            var data = rawdata.items;
            artistContent.total = parseInt(rawdata.total);
            for(var i in data) {
                var cover = "noCover.png"
                if(data[i].cover) {
                    cover = Utils.getCoverSource(data[i].cover.uri);
                }
                var genres = data[i].genres.join(',');
                artistModel.append({id: data[i].id, coverUri: cover, title: data[i].name, genre: genres, tracks: data[i].counts.tracks, albums: data[i].counts.directAlbums, alsoAlbums: data[i].counts.alsoAlbums})
            }
        }
    }

    function getTracks(rawdata) {
        if(rawdata !== "error") {
            var data = rawdata.items;
            trackContent.total = parseInt(rawdata.total);
            for(var i in data) {
                var cover = "noCover.png";
                var artists = [];
                for(var a in data[i].artists) {
                    artists.push(data[i].artists[a].name)
                }
                artists = artists.join(', ');
                if(data[i].album.coverUri) {
                    cover = Utils.getCoverSource(data[i].album.coverUri);
                }
                trackModel.append({artistId: data[i].artists[0].id, artists: artists, track: data[i].id, coverUri: cover, title: data[i].title, storageDir: data[i].storageDir, durationMs: data[i].durationMs, albumId: data[i].album.id, album: data[i].album.title, albumYear: data[i].album.year})
            }
        }
    }

    function fillData(data, errorString) {
        if(data !== "error") {
            var tmp = JSON.parse(data)
            getAlboms(tmp.albums);
            getArtists(tmp.artists);
            getTracks(tmp.tracks);
            busyIndicator.running = false;
            busyIndicator.visible = false;
            tabGroup.visible = true;
            contentTypes.visible = true;
        } else {
            console.log(data, errorString)
        }
    }

    Player {
        id: player
        height: 0;
    }

    ListModel {
        id: albumModel
    }

    ListModel {
        id: artistModel
    }

    ListModel {
        id: trackModel
    }

    Component {
        id: albumDelegate
        AlbumDelegate {
            height: 120
            width: parent.width
            iconSorce: coverUri
            itemText: title
            artistText: "<b>Исполнитель:</b> " + artists
            genreText: "<b>Жанр:</b> " + genre
            yearText: "<b>Год:</b> " + year
            albumId: id
            z: 3
        }
    }

    Component {
        id: albumPathViewDelegate
        AlbumPathViewDelegate {
            height: 500
            width: parent.width * 0.8
            iconSorce: coverUri
            itemText: title
            artistText: "<b>Исполнитель:</b> " + artists
            genreText: "<b>Жанр:</b> " + genre
            yearText: "<b>Год:</b> " + year
            albumId: id
            z: 3
        }
    }

    Component {
        id: artistDelegate
        ArtistDelegate {
            height: 110
            width: parent.width
            iconSorce: coverUri
            itemText: title
            genreText: "<b>Жанр:</b> " + genre
            tracksText: "<b>Треков:</b> " + tracks + " <b>Альбомов:</b> " + albums + " <b>Сборников:</b> " + alsoAlbums
            artistId: id
            z: 3
        }
    }

    Component {
        id: trackDelegate
        TrackDelegate {
            id: trackDelegate1
            height: 110
            width: parent.width
            trackId: track
            iconSorce: coverUri
            itemText: title
            artistText: "<b>Артист:</b> " + artists
            albumText: "<b>Альбом:</b> " + album
            yearText: "<b>Год:</b> " + albumYear
            trackSource: storageDir
            showIcon: true
            duration: durationMs
            z: 3

            onAddToPlaylist: {
//storageDir: trackSource, track: trackId, coverUri: iconSorce, title: itemText.text
                //playlist, artist, artistId, track, trackId, storageDir, art
                var currPlaylist = Utils.getCurrentPlayList();
                Utils.addToPlaylist(currPlaylist, artists, artistId, title, track, album, albumId, storageDir, coverUri, albumYear, durationMs);
            }
        }
    }

    Item {
        id: searchItem
        anchors.top: parent.top
        height: 60; //parent.height * 0.1
        width: parent.width
        // Search box without backbutton
        TextField {
            id: searchbox
            anchors.verticalCenter: parent.verticalCenter
            anchors.left: parent.left
            anchors.leftMargin: 10
            anchors.right: searchbutton.left
            placeholderText: "Артист, альбом, трек"
            ToolIcon {
                id: searchIcon
                anchors.right: parent.right
                anchors.verticalCenter: parent.verticalCenter
                platformIconId: "toolbar-search"
                enabled: false
            }
//            onSearchTextChanged: { ... }    // Get the current search text and do search operation.
        }
        Button {
            id: searchbutton
            anchors.verticalCenter: parent.verticalCenter
            anchors.right: parent.right
            anchors.rightMargin: 10
            width: parent.width * 0.25
            text: "Поиск"
            onClicked: {
                tabGroup.visible = false;
                busyIndicator.visible = true
                busyIndicator.running = true
                var url = "http://music.yandex.ru/handlers/search.jsx?text="+ searchbox.text +"&type=all";
                albumModel.clear();
                artistModel.clear();
                trackModel.clear();
                Utils.httpRequest("GET", url, fillData);
            }
        }
        Delimeter {
           width: parent.width * 0.98
        }
    }

    BusyIndicator {
        id: busyIndicator
        anchors.centerIn: parent
        running: false
        visible: false
        platformStyle: BusyIndicatorStyle { size: "large" }
    }

    TabGroup {
        id: tabGroup
        anchors.top: searchItem.bottom
        anchors.left: parent.left
        anchors.right: parent.right
        anchors.bottom: player.top
        currentTab: artistContent
        visible: false
        Page {
            id: artistContent
            orientationLock: PageOrientation.LockPortrait
            property int total: 0
            ListView {
                anchors.fill: parent
                clip: true
                spacing: 5
                model: artistModel
                delegate: artistDelegate
                footer: Item {
                    height: 120
                    visible: artistModel.count < artistContent.total?true:false
                    width: parent.width
                    Button {
                        id: footerText
                        anchors.centerIn: parent
                        text: "Показать ещё";
                        onClicked: {
                            artistModel.clear();
                            var url = "http://music.yandex.ru/handlers/search.jsx?text=" + searchbox.text + "&type=alrtists";
                            Utils.httpRequest("GET", url, fillData);
                        }
                    }
                }
            }
        }
        Page {
            id: albumContent
            orientationLock: PageOrientation.LockPortrait
            property int total: 0
            ListView {
                id: albumListView
                anchors.fill: parent
                clip: true
                visible: true
                spacing: 5
                model: albumModel
                delegate: albumDelegate
                footer: Item {
                    height: 120
                    visible: albumModel.count < albumContent.total?true:false
                    width: parent.width
                    Button {
                        id: footerText
                        anchors.centerIn: parent
                        text: "Показать ещё";
                        onClicked: {
                            albumModel.clear();
                            var url = "http://music.yandex.ru/handlers/search.jsx?text=" + searchbox.text + "&type=albums";
                            Utils.httpRequest("GET", url, fillData);
                        }
                    }
                }
            }
            PathView {
                id: albumPathView
                anchors.fill: parent
                clip: true
                z: 0
                visible: false
                delegate: albumPathViewDelegate
                model: albumModel

                path: Path {
                    startX: parent.width/2
                    startY: 0

                    PathAttribute { name: "itemZ"; value: 0 }
                    PathAttribute { name: "itemAngle"; value: -90.0; }
                    PathAttribute { name: "itemScale"; value: 0.5; }
                    PathLine { x: parent.width/2; y: parent.height*0.4; }
                    PathPercent { value: 0.48; }
                    PathLine { x: parent.width/2; y: parent.height*0.5; }
                    PathAttribute { name: "itemAngle"; value: 0.0; }
                    PathAttribute { name: "itemScale"; value: 1.0; }
                    PathAttribute { name: "itemZ"; value: 100 }
                    PathLine { x: parent.width/2; y: parent.height*0.6; }
                    PathPercent { value: 0.52; }
                    PathLine { x: parent.width/2; y: parent.height; }
                    PathAttribute { name: "itemAngle"; value: 90.0; }
                    PathAttribute { name: "itemScale"; value: 0.5; }
                    PathAttribute { name: "itemZ"; value: 0 }
                }

                pathItemCount: 16

                preferredHighlightBegin: 0.5
                preferredHighlightEnd: 0.5
            }
        }
        Page {
            id: trackContent
            orientationLock: PageOrientation.LockPortrait
            property int total: 0
            ListView {
                anchors.fill: parent
                clip: true
                spacing: 5
                model: trackModel
                delegate: trackDelegate
                footer: Item {
                    height: 120
                    visible: trackModel.count < trackContent.total?true:false
                    width: parent.width
                    Button {
                        id: footerText
                        anchors.centerIn: parent
                        text: "Показать ещё";
                        onClicked: {
                            trackModel.clear();
                            var url = "http://music.yandex.ru/handlers/search.jsx?text=" + searchbox.text + "&type=tracks";
                            Utils.httpRequest("GET", url, fillData);
                        }
                    }
                }
            }
        }
    }

    Menu {
        id: mainMenu
        content: MenuLayout {
            MenuItem {
                text: "Удалить базу данных"
                visible: true
                onClicked: {
                    Utils.dropTheBase();
                }
            }
            MenuItem {
                text: "Плейлист"
                visible: true
                onClicked: {
                    pageStack.push(Qt.resolvedUrl("PlaylistManagment.qml"))
                }
            }
            MenuItem {
                text: "Карусель"
                visible: false
                onClicked: {
                    albumListView.visible = !albumListView.visible;
                    albumPathView.visible = !albumPathView.visible;
                }
            }
            MenuItem {
                text: "Инвертированная тема"
                visible: false
                CheckBox {
                    id: themeCheckBox
                    anchors.right: parent.right
                    anchors.verticalCenter: parent.verticalCenter
                    checked: theme.inverted
                }

                onClicked: {
                    // Use the dark theme.
                    theme.inverted = !theme.inverted;
                    var tmp = theme.inverted;
                    Utils.setSetting('inverted', tmp.toString());
                }
            }
            MenuItem {
                text: "О программе"
                onClicked: {
                    aboutDialog.open();
                }
            }
        }
    }

    Dialog {
        id: aboutDialog
        anchors.centerIn: parent
        height: parent.height * 0.9
        width: parent.width * 0.9
        title: Text {
            id: titleItem
            anchors.top: parent.top
            anchors.left: parent.left
            anchors.right: parent.right
            height: 30
            width: parent.width
            text: "О программе"
            horizontalAlignment: Text.AlignHCenter
            color: "white"
            font.bold: true
            font.pixelSize: 24
            Delimeter {
                width: parent * 0.9
            }
        }
        content: Item {
            id: aboutContent
            anchors.top: titleItem.bottom
            anchors.left: parent.left
            anchors.right: parent.right
            height: 600
            width: parent.width
            Text {
                id: descrText
                horizontalAlignment: Text.AlignJustify
                verticalAlignment: Text.AlignJustify
                anchors.fill: parent
                anchors.margins: 5
                width: parent.width - 6
                font.pixelSize: 24
                z: 0
                clip: true
                text: "Права на все объекты размещенные на Сервисе Яндекс.Музыка, а также на базы данных, являющуюся совокупностью Материалов, размещенных на Сервисе Яндекс.Музыка, принадлежат <a href='http://company.yandex.com/'>Яндексу</a> <br><a href='http://legal.yandex.ru/music_termsofuse/'>Подробнее</a>";
                wrapMode: Text.WordWrap
                color: "white"

                onLinkActivated: {
                    Qt.openUrlExternally(link)
                }
            }
        }
        onClicked: {
            aboutDialog.close()
        }
    }

    tools: ToolBarLayout {
        id: tools
        ToolIcon {
            platformIconId: "toolbar-back"
            enabled: false
            opacity: 0.5
        }
        ButtonRow {
            id: contentTypes
            visible: false
            checkedButton: tab
            TabButton { id: tab; tab: artistContent; text: "Артист" }
            TabButton { tab: albumContent; text: "Альбом" }
            TabButton { tab: trackContent; text: "Трек";}
        }
        ToolIcon {
            platformIconId: "toolbar-view-menu"
            onClicked: mainMenu.open();
        }
    }
    //http://legal.yandex.ru/music_termsofuse/
/*
    Component {
        id: flipCardDelegate

        Item {
            id: wrapper

            width: 128
            height: 128

            visible: PathView.onPath

            scale: PathView.itemScale
            z: PathView.itemZ

            property variant rotX: PathView.itemAngle
            transform: Rotation { axis { x: 1; y: 0; z: 0 } angle: wrapper.rotX; origin { x: 32; y: 32; } }

            Rectangle {
                anchors.fill: parent
                color: "lightGray"
                border.color: "black"
                border.width: 3
            }

            Text {
                anchors.centerIn: parent
                text: index
                font.pixelSize: 30
            }
        }
    }

    PathView {
        anchors.fill: parent
        z: 1

        delegate: flipCardDelegate
        model: 100

        path: Path {
            startX: parent.width/2
            startY: 0

            PathAttribute { name: "itemZ"; value: 0 }
            PathAttribute { name: "itemAngle"; value: -90.0; }
            PathAttribute { name: "itemScale"; value: 0.5; }
            PathLine { x: parent.width/2; y: parent.height*0.4; }
            PathPercent { value: 0.48; }
            PathLine { x: parent.width/2; y: parent.height*0.5; }
            PathAttribute { name: "itemAngle"; value: 0.0; }
            PathAttribute { name: "itemScale"; value: 1.0; }
            PathAttribute { name: "itemZ"; value: 100 }
            PathLine { x: parent.width/2; y: parent.height*0.6; }
            PathPercent { value: 0.52; }
            PathLine { x: parent.width/2; y: parent.height; }
            PathAttribute { name: "itemAngle"; value: 90.0; }
            PathAttribute { name: "itemScale"; value: 0.5; }
            PathAttribute { name: "itemZ"; value: 0 }
        }

        pathItemCount: 16

        preferredHighlightBegin: 0.5
        preferredHighlightEnd: 0.5
    }*/
}
