import QtQuick 1.1
import com.nokia.meego 1.1
import com.nokia.extras 1.1     // Extras
import QtMultimediaKit 1.1

Item {

    property alias trackTitle: trackTitle.text
    property alias trackImage: currentTrack.source
//    property alias source: player.source

    property alias icon: currentTrack.source
    property alias buttonIcon: playerButton.iconId
    property alias isPlaying: player.playing
    property alias isPaused: player.paused

    property alias slider: progress
    property alias position: player.position

    property string trackId

    signal endOfMedia();

    onVisibleChanged: {
        console.log("Player visibility", visible)
    }

    Audio {
        id: player

        onSourceChanged: {
            playerButton.iconId = "toolbar-mediacontrol-play";
            console.log("Player source", source);
            play();
        }

        onError: {
            console.log(player.errorString)
        }

        onStarted: {
            playerButton.iconId = "toolbar-mediacontrol-pause";
            console.log("Song:", player.seekable);
        }

        onPaused: {
            playerButton.iconId = "toolbar-mediacontrol-play";
        }

        onResumed: {
            playerButton.iconId = "toolbar-mediacontrol-pause";
        }

        onStopped: {
            playerButton.iconId = "toolbar-mediacontrol-play";
        }

//        onPositionChanged: {
//            console.log(player.position)
//        }
        onStatusChanged: {
//            if(Audio.Loading || Audio.Buffering) {
//                playerButton.iconId = "toolbar-content-audio" //"toolbar-refresh"
//            }
            if(Audio.EndOfMedia && !player.playing) {
                console.log("Send signal for the next track")
                endOfMedia();
            }
        }
    }

    Component.onCompleted: {
//        cntrl = new PlayerControl.PlayerInstance();
//        if(parentItem) {
//            trackTitle = parentItem.trackTitle
//            currentTrack = parentItem.currentTrack
//            source = parentItem.source
//        }
//        albumInfo.trackChanged.connect(sendReqest);
//        trackDelegate1.changeTrackSignal.connect(sendReqest);
    }

    function play() {
        player.play();
    }

    function stop() {
        player.stop();
    }

    function pause() {
        player.pause();
    }

    function getTrackSource(data, error) {
        if(data !== "error" && trackId) {
            var json;
            var jsonp = data.replace('Ya.Music.Jsonp.', '');
            var f = new Function('callback', jsonp);
            try {
                f(function (requestId, parsedJson) {
                    json = parsedJson[0];
                });
            } catch (e) {
                console.log('Не удалось распарсить jsonp.' + e);
                return;
            }
            var word = 'XGRlBW9FXlekgbPrRHuSiA' + json.path.substr(1) + json.s;
            var hexsum = Qt.md5(word);
            var url = "http://" + json.host + "/get-mp3/" + hexsum + "/" + json.ts + json.path + "?track-id=" + trackId;
            player.source = url;
        } else {
            console.log(error)
        }
    }

    function sendReqest(data) {
        console.log("changeTrack ", JSON.stringify(data), "\nmainPage.changeTrack", mainPage.changeTrack)
        if(mainPage.changeTrack) {
            trackId = data.track;
            trackTitle.text = data.title;
            currentTrack.source = data.coverUri;
            var url = "http://music.yandex.ru/api/v1.4/jsonp.xml?action=getTrackSrc&p=download-info/" + data.storageDir + "/2.mp3";
            myWorker.sendMessage( { requestType: "GET", url: url} );
            mainPage.changeTrack = false;
        }
    }

    WorkerScript {
        id: myWorker
        source: "WorkerScipt.js"

        onMessage: {
            console.log("Result " + messageObject.responseText);
            getTrackSource(messageObject.responseText);
        }
    }

    anchors.left: parent.left
    anchors.right: parent.right
    anchors.bottom: parent.bottom
    height: 0; // 110;
    visible: false;
    Delimeter {
        anchors.top: parent.top
        width: parent.width
    }

    Image {
        id: currentTrack
        anchors.top: parent.top
        anchors.topMargin: 10
        anchors.left: parent.left
        anchors.leftMargin: 10
//        anchors.verticalCenter: parent.verticalCenter
        height: 150
        width: 150
        fillMode: Image.PreserveAspectFit
        smooth: true
        source: "noCover.png"
    }
    Text {
        id: trackTitle
        anchors.left: currentTrack.right
        anchors.leftMargin: 10
        anchors.right: playerButton.left
        anchors.rightMargin: 10
//        anchors.verticalCenter: parent.verticalCenter
        anchors.top: currentTrack.top
        wrapMode: Text.WordWrap
        horizontalAlignment: Text.AlignHCenter
        font.pixelSize: 18
        text: ""
    }
    ToolIcon {
        id: playerButton
        anchors.right: parent.right
        anchors.rightMargin: 10
        anchors.verticalCenter: parent.verticalCenter
        iconId: "toolbar-mediacontrol-play"
        onClicked: {
            if(player.playing && !player.paused) {
                player.pause();
                playerButton.iconId = "toolbar-mediacontrol-play";
            } else {
                player.play();
                playerButton.iconId = "toolbar-mediacontrol-pause";
            }
        }
    }
    Slider {
        id: progress
        anchors.left: currentTrack.right
        anchors.leftMargin: 5
        anchors.bottom: parent.bottom
        anchors.bottomMargin: 10
        anchors.right: parent.right
        anchors.rightMargin: 5
//        anchors.horizontalCenter: parent.horizontalCenter
        width: parent.width * 0.8
        maximumValue: player.duration
        value: player.position
        valueIndicatorVisible: true
        valueIndicatorText: ((value/player.duration)*100).toFixed(2) + "%"
        onValueChanged: {
            if(pressed) {
                player.position = value;
                valueIndicatorText = ((value/player.duration)*100).toFixed(2) + "%"
            }
        }
        onPressedChanged: {
            if(pressed) {
                player.pause()
            } else {
                player.position = value;
                player.play()
            }
        }
    }
}
