// import QtQuick 1.0 // to target S60 5th Edition or Maemo 5
import QtQuick 1.1
import com.nokia.meego 1.1

import "Utils.js" as Utils

Page {
    id: playlistPage
    orientationLock: PageOrientation.LockPortrait

    signal changeTrackSignal(variant data);

    Component.onCompleted: {
        fillData();
        changeTrackSignal.connect(mainPage.playerAlias.sendReqest);        
        mainPage.playerAlias.endOfMedia.connect(playlistPage.nextTrack);
    }

    function nextTrack(){
        if(listView.count > 0 && listView.currentIndex < listView.count){
            mainPage.changeTrack = true;
            mainPage.playerAlias.pause();
            listView.incrementCurrentIndex();
            changeTrackSignal(playlistElements.get(listView.currentIndex));
        }
    }

    function fillData() {
        var currPlaylist = Utils.getCurrentPlayList();
        playlistElements.clear();
        var res = Utils.getPlaylist(currPlaylist);
        if (res.constructor === Array) {
            for(var i in res) {
                //playlist_name TEXT, artist TEXT, artistId TEXT, track TEXT, trackId TEXT, storageDir TEXT, url TEXT
                playlistElements.append({artistId: res[i].artistId, artists: res[i].artist, album: res[i].album, track: res[i].trackId, coverUri: res[i].url, title: res[i].track, storageDir: res[i].storageDir, albumYear: res[i].albumYear, durationMs: res[i].durationMs})
            }
        }
    }

    ListModel {
        id: playlistElements
    }

    Component {
        id: playlistElementsDelegate
        TrackDelegate {
            height: 110
            width: parent.width
            trackId: track
            iconSorce: coverUri
            itemText: title
            artistText: "<b>Артист:</b> " + artists
            albumText: "<b>Альбом:</b> " + album
            yearText: "<b>Год:</b> " + albumYear
            trackSource: storageDir
            duration: durationMs
            showIcon: true
            z: 3
            onDeleteFromPlaylist: {
                Utils.deleteRecord(artistId, track);
                fillData();
            }
        }
    }

    ContextMenu {
        id: playlistContext
        MenuLayout {
            MenuItem {
                text: "Удалить из " + Utils.getCurrentPlayList();
                onClicked: {
////storageDir: trackSource, track: trackId, coverUri: iconSorce, title: itemText.text
//                    //playlist, artist, artistId, track, trackId, storageDir, art
//                    var currPlaylist = getCurrentPlaylist();
//                    Utils.addToPlaylist(currPlaylist, itemText, "0", );
                    Utils.deleteRecord(_artistId, _trackId);
                    fillData();
                }
            }
        }
    }

    SelectionDialog {
         id: dialog1
         titleText: "Default playlist:"
         model: ListModel {
             ListElement { name: "Rock" }
             ListElement { name: "Paper" }
             ListElement { name: "Scissors" }
         }
         delegate: Text {
             text: name
             color: "white"
         }
    }


    ListView {
        id: listView
        anchors.top: parent.top
        anchors.left: parent.left
        anchors.right: parent.right
        anchors.bottom: playerItem.top
        model: playlistElements
        delegate: playlistElementsDelegate
        clip: true
        spacing: 5
    }

    Item {
        id: playerItem
        anchors.left: parent.left
        anchors.right: parent.right
        anchors.bottom: parent.bottom
        height: mainPage.playerAlias.height;
        visible: mainPage.playerAlias.trackTitle!==""?true:false;

        Delimeter {
            anchors.top: parent.top
            width: parent.width
        }

        Image {
            id: currentTrack
            anchors.left: parent.left
            anchors.leftMargin: 10
            anchors.verticalCenter: parent.verticalCenter
            height: 150
            width: 150
            fillMode: Image.PreserveAspectFit
            smooth: true
            source: mainPage.playerAlias.icon
        }
        Text {
            id: title
            anchors.left: currentTrack.right
            anchors.leftMargin: 10
            anchors.right: parent.right
            anchors.rightMargin: 10
            anchors.top: parent.top
            anchors.topMargin: 5
//            anchors.verticalCenter: parent.verticalCenter
            wrapMode: Text.WordWrap
            horizontalAlignment: Text.AlignHCenter
            font.pixelSize: 18
            text: mainPage.playerAlias.trackTitle
        }
        Slider {
            anchors.left: currentTrackTime.right
            anchors.leftMargin: 10
            anchors.right: trackDurationTime.left
            anchors.rightMargin: 10
            anchors.verticalCenter: currentTrackTime.verticalCenter
//            anchors.bottom: currentTrackTime.top
            value: mainPage.playerAlias.position
            maximumValue: mainPage.playerAlias.slider.maximumValue
            valueIndicatorVisible: true
            valueIndicatorText: ((value/maximumValue)*100).toFixed(2) + "%"
            onValueChanged: {
                if(pressed) {
                    mainPage.playerAlias.position = value;
                    valueIndicatorText = ((value/maximumValue)*100).toFixed(2) + "%"
                }
            }
            onPressedChanged: {
                if(pressed) {
                    mainPage.playerAlias.pause()
                } else {
                    mainPage.playerAlias.position = value;
                    mainPage.playerAlias.play()
                }
            }
        }
        Text {
            id: currentTrackTime
            anchors.left: currentTrack.right
            anchors.leftMargin: 10
            anchors.bottom: parent.bottom
            anchors.bottomMargin: 15
            text: Utils.getDurationTime(mainPage.playerAlias.position)
        }
        Text {
            id: trackDurationTime
            anchors.right: parent.right
            anchors.rightMargin: 10
            anchors.bottom: parent.bottom
            anchors.bottomMargin: 15
            text: Utils.getDurationTime(mainPage.playerAlias.slider.maximumValue)
        }

        onVisibleChanged: {
            console.log("Item", mainPage.playerAlias.visible, mainPage.playerAlias.trackTitle, mainPage.playerAlias.icon)
        }
    }

    tools: ToolBarLayout {
        id: tools
        ToolIcon {
            id: backButton
            platformIconId: "toolbar-back"
            onClicked: {
                pageStack.pop();
            }
        }
        ToolIcon {
            id: prevButton
            iconId: "toolbar-mediacontrol-previous"
            onClicked: {
                if(listView.count > 0 && listView.currentIndex > 0){
                    mainPage.playerAlias.pause();
                    mainPage.changeTrack = true;
                    listView.decrementCurrentIndex();
                    changeTrackSignal(playlistElements.get(listView.currentIndex));
                }
            }
        }

        ToolIcon {
            id: playerButton
            iconId: mainPage.playerAlias.buttonIcon
            onClicked: {
                if(mainPage.playerAlias.isPlaying && !mainPage.playerAlias.isPaused) {
                    mainPage.playerAlias.pause();
                } else {
                    mainPage.playerAlias.play();
                }
            }
        }
        ToolIcon {
            id: nextButton
            iconId: "toolbar-mediacontrol-next"
            onClicked: {
                nextTrack();
            }
        }
        ToolIcon {
            platformIconId: "toolbar-view-menu"
            enabled: false
            onClicked: dialog1.open();
        }
    }
}
