import QtQuick 1.1
import com.nokia.meego 1.1

import "Utils.js" as Utils

Item {
    property alias itemText: itemText.text
    property alias artistText: artistText.text
    property alias iconSorce: iconImage.source
    property alias albumText: albumText.text
    property alias yearText: yearText.text

    property string trackSource
    property string trackId
    property string duration

    property bool showIcon: false

    property bool deleteTrack: false

    signal changeTrackSignal(variant data);
    signal addToPlaylist();
    signal deleteFromPlaylist();

    Component.onCompleted: {
        Utils.initialize();
        if(Utils.getCurrentPlayList() === "Error") {
            Utils.setPlaylist("Default");
        }
        changeTrackSignal.connect(mainPage.playerAlias.sendReqest)
    }

    function getCurrentPlaylist() {
        return Utils.getCurrentPlayList();
    }

    Image {
        id: iconImage
        anchors.left: parent.left
        anchors.leftMargin: 10
        anchors.verticalCenter: parent.verticalCenter
        height: showIcon?100:0
        width: showIcon?100:0
        fillMode: Image.PreserveAspectFit
        smooth: true
        source: "noCover.png"
        visible: showIcon
    }
    Text {
        id: itemText
        anchors.top: iconImage.top
        anchors.left: iconImage.right
        anchors.leftMargin: 5
        anchors.right: parent.right
        anchors.rightMargin: 5
        wrapMode: Text.WordWrap
        horizontalAlignment: Text.AlignHCenter
        font.pixelSize: 24
        text: qsTr("Album name")
        visible: showIcon
    }
    Text {
        id: itemTextAlbum
        anchors.verticalCenter: parent.verticalCenter
        anchors.left: parent.left
        anchors.leftMargin: 5
        anchors.right: durationText.left
        anchors.rightMargin: 5
        wrapMode: Text.WordWrap
        horizontalAlignment: Text.AlignHCenter
        font.pixelSize: 24
        text: itemText.text
        visible: !showIcon
    }
    Text {
        id: artistText
        anchors.bottom: albumText.top
        anchors.left: iconImage.right
        anchors.leftMargin: 5
        anchors.right: parent.right
        anchors.rightMargin: 5
        wrapMode: Text.WordWrap
        text: qsTr("artist")
        visible: showIcon
    }
    Text {
        id: albumText
        anchors.bottom: yearText.top
        anchors.left: iconImage.right
        anchors.leftMargin: 5
        anchors.right: parent.right
        anchors.rightMargin: 5
        wrapMode: Text.WordWrap
        text: qsTr("album")
        visible: showIcon
    }
    Text {
        id: yearText
        anchors.bottom: iconImage.bottom
        anchors.left: iconImage.right
        anchors.leftMargin: 5
        wrapMode: Text.WordWrap
        text: qsTr("year")
        opacity: 0.8
        visible: showIcon
    }
    Text {
        id: durationText
        anchors.verticalCenter: parent.verticalCenter
        anchors.right: parent.right
        anchors.rightMargin: 5
        wrapMode: Text.WordWrap
        text: Utils.getDurationTime(duration);
        font.pixelSize: 14
        visible: true
    }

    Delimeter {
       width: parent.width * 0.95
    }

//    Dialog {
//        id: playlistDialog
//        anchors.centerIn: parent
//        height: parent.height * 0.9
//        width: parent.width * 0.9
//        title: Text {
//            id: titleItem
//            anchors.top: parent.top
//            anchors.left: parent.left
//            anchors.right: parent.right
//            height: 30
//            width: parent.width
//            text: "Добавить в плейлист"
//            horizontalAlignment: Text.AlignHCenter
//            color: "white"
//            font.bold: true
//            font.pixelSize: 24
//            Delimeter {
//                width: parent * 0.9
//            }
//        }
//        content: Item {
//            id: playlistContent
//            anchors.top: titleItem.bottom
//            anchors.left: parent.left
//            anchors.right: parent.right
//            height: 600
//            width: parent.width
//            Text {
//                id: descrText
//                horizontalAlignment: Text.AlignJustify
//                verticalAlignment: Text.AlignJustify
//                anchors.fill: parent
//                anchors.margins: 5
//                width: parent.width - 6
//                font.pixelSize: 24
//                z: 0
//                clip: true
//                text: "Права на все объекты размещенные на Сервисе Яндекс.Музыка, а также на базы данных, являющуюся совокупностью Материалов, размещенных на Сервисе Яндекс.Музыка, принадлежат <a href='http://company.yandex.com/'>Яндексу</a> <br><a href='http://legal.yandex.ru/music_termsofuse/'>Подробнее</a>";
//                wrapMode: Text.WordWrap
//                color: "white"

//                onLinkActivated: {
//                    Qt.openUrlExternally(link)
//                }
//            }
//        }
//        onClicked: {
//            playlistDialog.close()
//        }
//    }

    ContextMenu {
        id: playlistContext
        MenuLayout {
            MenuItem {
                text: "Добавить в " + getCurrentPlaylist();
                visible: !deleteTrack
                onClicked: {
////storageDir: trackSource, track: trackId, coverUri: iconSorce, title: itemText.text
//                    //playlist, artist, artistId, track, trackId, storageDir, art
//                    var currPlaylist = getCurrentPlaylist();
//                    Utils.addToPlaylist(currPlaylist, itemText, "0", );
                    addToPlaylist();
                }
            }
            MenuItem {
                text: "Удалить из " + Utils.getCurrentPlayList();
                visible: deleteTrack
                onClicked: {
////storageDir: trackSource, track: trackId, coverUri: iconSorce, title: itemText.text
//                    //playlist, artist, artistId, track, trackId, storageDir, art
//                    var currPlaylist = getCurrentPlaylist();
//                    Utils.addToPlaylist(currPlaylist, itemText, "0", );
                    deleteFromPlaylist();
//                        Utils.deleteRecord(_artistId, _trackId);
//                        fillData();
                }
            }
            MenuItem {
                text: "Сменить плейлист"
                visible: false
            }
        }
    }

    MouseArea {
        anchors.fill: parent
        onClicked: {
            if (trackSource) {
                mainPage.changeTrack = true
                var tmp = {storageDir: trackSource, track: trackId, coverUri: iconSorce, title: itemText.text};
                changeTrackSignal(tmp);
                if(!mainPage.playerAlias.visible) {
                    mainPage.playerAlias.height = 180;
                    mainPage.playerAlias.visible = true;
                }
            }
        }
        onPressAndHold: {
//            playlistDialog.open()
            playlistContext.open()
        }
    }
}
