function httpRequest(requestType, url, callback) {
    var request = new XMLHttpRequest();
    request.onreadystatechange = function() {
                if (request.readyState == 4) {
                    if (request.status == 200) {
                        callback(request.responseText, "");
                    }
                    else
                    {
                        callback("error", request.getResponseHeader);
                    }
                }
            }
    request.open(requestType, url);
    request.send();
    console.log("Send request:", url);
}

function getCoverSource(data) {
    if(data){
        return "http://" + data.replace("%%", "200x200");
    } else {
        return "noCover.png";
    }
}

function getDurationTime(data) {
    if(data) {
        var t = data/1000
        var minute = Math.floor(t/60);
        var seconds = parseInt(t - minute * 60);
        if(seconds < 10) {
            return minute + ":0" + seconds
        } else {
            return minute + ":" + seconds
        }
    }
    return "0:00"
}

// First, let's create a short helper function to get the database connection
function getDatabase() {
     return openDatabaseSync("yaMusic", "1.0", "StorageDatabase", 100000);
}

// At the start of the application, we can initialize the tables we need if they haven't been created yet
function initialize() {
    var db = getDatabase();
    db.transaction(
        function(tx) {
            // Create the settings table if it doesn't already exist
            // If the table exists, this is skipped
            tx.executeSql('CREATE TABLE IF NOT EXISTS playlist(playlist_name TEXT, artist TEXT, artistId TEXT, track TEXT, trackId TEXT, album TEXT, albumId TEXT, storageDir TEXT, url TEXT, albumYear TEXT, durationMs TEXT)');
            tx.executeSql('CREATE TABLE IF NOT EXISTS settings(name TEXT UNIQUE, value TEXT)');
            tx.executeSql('CREATE TABLE IF NOT EXISTS currentPlayList(value TEXT)');
      });
}

function setSetting(name, value) {
    var db = getDatabase();
    var res = "Error";
    db.transaction(function(tx) {
         var rs = tx.executeSql('INSERT OR REPLACE INTO settings VALUES (?,?);', [name,value]);
               //console.log(rs.rowsAffected)
               if (rs.rowsAffected > 0) {
                 res = "OK";
               } else {
                 res = "Error";
               }
         }
   );
   // The function returns “OK” if it was successful, or “Error” if it wasn't
   return res;
}

function getSetting(name) {
    var db = getDatabase();
    var res = "Error";
    db.transaction(function(tx) {
                       var rs = tx.executeSql('select value FROM settings WHERE name = ?;', [name]);
                       if (rs.rows.length > 0) {
                            res = rs.rows.item(0).value
                       }
                   })
    return res;
}

//Set current playlist
function setPlaylist(name) {
    var db = getDatabase();
    var res = "Error";
    db.transaction(function(tx) {
         var rs = tx.executeSql('REPLACE INTO currentPlayList VALUES (?);', [name]);
               //console.log(rs.rowsAffected)
               if (rs.rowsAffected > 0) {
                 res = "OK";
               } else {
                 res = "Error";
               }
         }
   );
   // The function returns “OK” if it was successful, or “Error” if it wasn't
   return res;
}

//Get current playlist
function getCurrentPlayList() {
    var db = getDatabase();
    var res = "Error";
    db.transaction(function(tx) {
                       var rs = tx.executeSql('select value FROM currentPlayList');
                       if (rs.rows.length > 0) {
                            res = rs.rows.item(0).value
                       }
                   })
    return res;
}

// This function is used to write a favorite record into the database
function addToPlaylist(playlist, artist, artistId, track, trackId, album, albumId, storageDir, art, albumYear, durationMs) {
   // setting: string representing the setting name (eg: “username”)
   // value: string representing the value of the setting (eg: “myUsername”)
   var db = getDatabase();
   var res = "";
   db.transaction(function(tx) {
                      //playlist_name TEXT, artist TEXT, artistId TEXT, track TEXT, trackId TEXT, storageDir TEXT, url TEXT, albumYear TEXT, durationMs TEXT
        var rs = tx.executeSql('INSERT OR REPLACE INTO playlist VALUES (?,?,?,?,?,?,?,?,?,?,?);', [playlist, artist, artistId, track, trackId, album, albumId, storageDir, art, albumYear, durationMs]);
              //console.log(rs.rowsAffected)
              if (rs.rowsAffected > 0) {
                res = "OK";
              } else {
                res = "Error";
              }
        }
  );
  // The function returns “OK” if it was successful, or “Error” if it wasn't
  return res;
}
// This function is used to retrieve a list of favorite tracks from the database
function getPlaylist(playlist) {
    var db = getDatabase();
    var err = "Error";
    var res = new Array;
    db.transaction(function(tx) {
                       var rs = tx.executeSql('SELECT * FROM playlist WHERE playlist_name = (?);', [playlist]);
                       if (rs.rows.length > 0) {
                           for(var i = 0; i < rs.rows.length; i++) {
                               res.push(rs.rows.item(i));
                           }
                       }
                   })
    // The function returns Error if the value was not found in the database
    // For more advanced projects, this should probably be handled through error codes
    if(res.length > 0) {
        return res;
    } else {
        return err;
    }
}

function isTrackPresent(track_id) {
    var db = getDatabase();
    var res = false;
    db.transaction(function(tx) {
                       var request = 'select * FROM favorites WHERE track_id = ' + track_id + ';'
                       var rs = tx.executeSql(request);
                       if (rs.rows.length > 0) {
                           res = true;
                       }
                   });
    return res;

}

function deleteRecord(artistId, trackId) {
    var db = getDatabase();
    var res = false;
    db.transaction(function(tx) {
                       var request = 'DELETE FROM playlist WHERE artistId = ' + artistId + ' AND trackId=' + trackId + ';'
                       res = tx.executeSql(request);
                   });
    return res;
}

//drop the base
function dropTheBase() {
    var db = getDatabase();
    db.transaction(
        function(tx) {
            // Delete the favorites table if it already exists
            tx.executeSql('DROP TABLE IF EXISTS playlist');
           // tx.executeSql('DROP TABLE IF EXISTS settings');
      });
}
